@@ -78,7 +78,7 @@ void cipher_gen(void)
             printf("keysize error: %s\n", error_to_string(err));
             exit(EXIT_FAILURE);
          }
-         if (kl == lastkl) break;
+         if (kl == lastkl) continue;
          lastkl = kl;
          fprintf(out, "Key Size: %d bytes\n", kl);
 
@@ -797,6 +797,6 @@ int main(void)
    return 0;
 }
 
-/* ref:         HEAD -> master, tag: v1.18.1 */
-/* git commit:  e08fd8630f9d9771226466877064055ee7e863d0 */
-/* commit time: 2018-01-22 11:02:57 +0100 */
+/* ref:         HEAD -> master, tag: v1.18.2 */
+/* git commit:  7e7eb695d581782f04b24dc444cbfde86af59853 */
+/* commit time: 2018-07-01 22:49:01 +0200 */
